@@ -1,6 +1,6 @@
 package POE::Component::Server::IRC::Backend;
 our $AUTHORITY = 'cpan:BINGOS';
-$POE::Component::Server::IRC::Backend::VERSION = '1.55'; # TRIAL
+$POE::Component::Server::IRC::Backend::VERSION = '1.56'; # TRIAL
 use strict;
 use warnings;
 use Carp qw(carp croak);
@@ -852,7 +852,7 @@ sub add_denial {
     my $netmask = shift || return;
     my $reason = shift || 'Denied';
 
-    if ( !$netmask->isa('Net::Netmask') ) {
+    if ( ! eval { $netmask->isa('Net::Netmask') } ) {
       $netmask = Net::CIDR::cidrvalidate( $netmask );
     }
 
@@ -909,7 +909,7 @@ sub denied {
     return if $self->exempted($ipaddr);
 
     for my $mask (keys %{ $self->{denials} }) {
-        if ($self->{denials}{$mask}{blk}->isa('Net::Netmask') && $self->{denials}{$mask}{blk}->match($ipaddr)) {
+        if ( eval { $self->{denials}{$mask}{blk}->isa('Net::Netmask') } && $self->{denials}{$mask}{blk}->match($ipaddr)) {
             return $self->{denials}{$mask}{reason};
         }
         elsif ( Net::CIDR::cidrlookup( $ipaddr, $self->{denials}{$mask}{blk} ) ) {
